@@ -1,5 +1,5 @@
 #' @title
-#' Check Additional Arguments
+#' Check additional arguments
 #'
 #' @description
 #' Checks additional arguments that user needs to provide for different
@@ -16,11 +16,10 @@
 #'
 #' @keywords internal
 #'
-#'
 check_args <- function(ci_appr,
                        use_cov_transform, transformers,
                        gps_model, trim_quantiles,
-                       optimized_compile, ...){
+                       ...) {
 
   # 1) Check if the main arguments are correct.
   # 2) Generate required arguments based on main arguments.
@@ -34,26 +33,25 @@ check_args <- function(ci_appr,
   dot_args <- list(...)
   arg_names <- names(dot_args)
 
-  for (i in arg_names){
-    assign(i,unlist(dot_args[i],use.names = FALSE))
+  for (i in arg_names) {
+    assign(i, unlist(dot_args[i], use.names = FALSE))
   }
 
   # check for trimming values
-  if (!is.numeric(trim_quantiles)){
+  if (!is.numeric(trim_quantiles)) {
     stop("trim_quantiles should be numeric values.")
   }
 
   if ((trim_quantiles[1] < 0 || trim_quantiles[1] > 1) ||
       (trim_quantiles[2] < 0 || trim_quantiles[2] > 1) ||
-      (trim_quantiles[1] > trim_quantiles[2])){
+      (trim_quantiles[1] > trim_quantiles[2])) {
     stop(paste("trim_quntiles should be in the [0,1] range,",
                " and the first quantile should be less than the second one."))
   }
 
   check_args_estimate_gps(gps_model, ...)
   check_args_generate_pseudo_pop(max_attempt = max_attempt)
-  check_args_compile_pseudo_pop(ci_appr,
-                                optimized_compile, ...)
+  check_args_compile_pseudo_pop(ci_appr, ...)
   check_args_use_cov_transformers(use_cov_transform, transformers)
 
   invisible(TRUE)
@@ -138,8 +136,7 @@ check_args_generate_pseudo_pop <- function(max_attempt){
 #'
 #' @keywords internal
 #'
-check_args_compile_pseudo_pop <- function(ci_appr,
-                                          optimized_compile, ...){
+check_args_compile_pseudo_pop <- function(ci_appr, ...){
 
   # Passing packaging check() ----------------------------
   covar_bl_method <- NULL
@@ -155,12 +152,6 @@ check_args_compile_pseudo_pop <- function(ci_appr,
     stop(paste(ci_appr, " is not a valid causal inference approach."))
   }
 
-  if (!is.logical(optimized_compile)){
-    stop(paste("optimized_compile: ", optimized_compile," is not valid.",
-    "It should be a logical value."))
-  }
-
-
   # checkpoint 2 ------------------------------------------
   if (ci_appr == 'matching'){
     required_args <- c(required_args, 'covar_bl_method', 'covar_bl_trs',
