@@ -20,7 +20,6 @@
 #'  (Default is 0.5).
 #' @param delta_n a specified caliper parameter on the exposure (Default is 1).
 #' @param nthread Number of available cores.
-#' @param optimized_compile An option to activate optimized compilation.
 #' @param gps_model Model type which is used for estimating GPS value, including
 #' parametric (default) and non-parametric.
 #' @return
@@ -38,11 +37,9 @@ matching_l1 <- function(w,
                         gps_mx,
                         w_mx,
                         gps_model = "parametric",
-                        delta_n=1,
-                        scale=0.5,
-                        nthread=1,
-                        optimized_compile)
-{
+                        delta_n = 1,
+                        scale = 0.5,
+                        nthread = 1) {
 
   if (length(w)!=1){
     stop("w should be a vector of size 1.")
@@ -52,7 +49,7 @@ matching_l1 <- function(w,
   st_ml_t <- proc.time()
 
   if (gps_model == "parametric"){
-    p_w <- stats::dnorm(w, mean = e_gps_pred, sd=e_gps_std_pred)
+    p_w <- stats::dnorm(w, mean = e_gps_pred, sd = e_gps_std_pred)
   } else if (gps_model == "non-parametric") {
     w_new <- compute_resid(w, e_gps_pred, e_gps_std_pred)
     p_w <- compute_density(w_resid, w_new)
@@ -76,11 +73,11 @@ matching_l1 <- function(w,
   std_w <- (w - w_min) / (w_max - w_min)
   std_p_w <- (p_w - gps_min) / (gps_max - gps_min)
 
-  dataset_subset <- dataset[abs(dataset[["w"]] - w) <= (delta_n/2), ]
+  dataset_subset <- dataset[abs(dataset[["w"]] - w) <= (delta_n / 2), ]
 
   if (nrow(dataset_subset) < 1){
     logger:: log_warn(paste("There is no data to match with ", w, "in ",
-                            delta_n/2,
+                            delta_n / 2,
                             " radius."))
     return(list())
   }
@@ -93,7 +90,7 @@ matching_l1 <- function(w,
                              nthread)
 
 
-  dp <- dataset_subset[wm,]
+  dp <- dataset_subset[wm, ]
 
   dp["std_w"] <- NULL
   dp["std_gps"] <- NULL
@@ -102,18 +99,16 @@ matching_l1 <- function(w,
   logger::log_debug("Finished matching on single w value (w = {w}), ",
                     " Wall clock time: {(e_ml_t - st_ml_t)[[3]]} seconds.")
 
-  if (!optimized_compile){
-    return(dp)
-  } else {
-    row_index <- NULL
-    row_index_data <- dp["row_index"]
-    row.names(row_index_data) <- NULL
-    data.table::setDT(row_index_data)
-    freq_table <- row_index_data[ , .N, by=row_index]
-    freq_table <- freq_table[order(row_index)]
-    row.names(freq_table) <- NULL
-    row_index_data <- NULL
 
-    return(freq_table)
-  }
+  row_index <- NULL
+  row_index_data <- dp["row_index"]
+  row.names(row_index_data) <- NULL
+  data.table::setDT(row_index_data)
+  freq_table <- row_index_data[ , .N, by=row_index]
+  freq_table <- freq_table[order(row_index)]
+  row.names(freq_table) <- NULL
+  row_index_data <- NULL
+
+  return(freq_table)
+
 }
