@@ -1,14 +1,26 @@
 #include <Rcpp.h>
-#include <omp.h>
 using namespace Rcpp;
 
+#ifdef _OPENMP
+  #include <omp.h>
+#else
+  #define omp_get_num_threads()  1
+  #define omp_get_thread_num()   0
+  #define omp_get_max_threads()  1
+  #define omp_get_thread_limit() 1
+  #define omp_get_num_procs()    1
+  #define omp_set_nested(a)   // empty statement to remove the call
+  #define omp_get_wtime()        0
+#endif
+
 // [[Rcpp::plugins(openmp)]]
 
 // [[Rcpp::export]]
 IntegerVector compute_closest_wgps_helper(NumericVector a,
                                           NumericVector b,
                                           NumericVector cd,
-                                          double sc) {
+                                          double sc,
+                                          int nthread) {
 
   // a is the subset of data
   // b is the original data
@@ -18,21 +30,21 @@ IntegerVector compute_closest_wgps_helper(NumericVector a,
 
   int size_a = a.size();
   int size_b = b.size();
-  int min_index = 0;
-  double min_val = 0;
-  double tmp_val = 0;
-  double subtract_val = 0;
 
-  NumericVector tmp(size_a);
   IntegerVector out(size_b);
 
-
   #if defined(_OPENMP)
-  int nthread = omp_get_max_threads();
-  omp_set_num_threads(nthread);
-  #pragma omp parallel for
+    //int nthread = omp_get_max_threads();
+    omp_set_num_threads(nthread);
+    #pragma omp parallel for
   #endif
   for(int i = 0; i < size_b; ++i) {
+
+    double tmp_val = 0;
+    int min_index = 0;
+    double min_val = 0;
+    double subtract_val = 0;
+
     for(int j=0; j < size_a; ++j) {
 
       subtract_val = (b[i]-a[j])*sc;
