@@ -8,7 +8,6 @@ test_that("create_weighting works as expected.", {
                                     ci_appr = "matching",
                                     gps_model = "non-parametric",
                                     trim_quantiles = c(0.01,0.99),
-                                    optimized_compile = FALSE,
                                     sl_lib = c("SL.xgboost"),
                                     covar_bl_method = "absolute",
                                     covar_bl_trs = 0.1,
@@ -27,9 +26,8 @@ test_that("create_weighting works as expected.", {
 
   expect_false(pseudo_pop$passed_covar_test)
   expect_equal(length(pseudo_pop$pseudo_pop), 11)
-  expect_false(pseudo_pop$optimized_compile)
-  expect_equal(nrow(pseudo_pop$pseudo_pop),2058)
-  expect_equal(mean(pseudo_pop$pseudo_pop$Y), -34.54658, tolerance = 0.0001)
+  expect_equal(nrow(pseudo_pop$pseudo_pop),98)
+  expect_equal(mean(pseudo_pop$pseudo_pop$Y), -37.32878, tolerance = 0.0001)
 })
 
 
@@ -45,7 +43,6 @@ test_that("create_weighting works as expected.", {
                                     ci_appr = "matching",
                                     gps_model = "non-parametric",
                                     trim_quantiles = c(0.01,0.99),
-                                    optimized_compile = FALSE,
                                     sl_lib = c("SL.xgboost","SL.earth","SL.gam"),
                                     covar_bl_method = "absolute",
                                     covar_bl_trs = 0.1,
@@ -58,14 +55,11 @@ test_that("create_weighting works as expected.", {
   dataset <- pseudo_pop$pseudo_pop
   dataset1 <- dataset[, !c("w")]
 
-  # expect error if there is no column with "w"
   expect_error(create_weighting(dataset = dataset1))
 
-
   expect_false(pseudo_pop$passed_covar_test)
   expect_equal(length(pseudo_pop$pseudo_pop), 11)
-  expect_false(pseudo_pop$optimized_compile)
-  expect_equal(nrow(pseudo_pop$pseudo_pop),2058)
-  expect_equal(mean(pseudo_pop$pseudo_pop$Y), -33.26108, tolerance = 0.0001)
+  expect_equal(nrow(pseudo_pop$pseudo_pop), 98)
+  expect_equal(mean(pseudo_pop$pseudo_pop$Y), -37.32878, tolerance = 0.0001)
 })
 
