@@ -20,7 +20,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                  ci_appr = "matching",
                                  gps_model = "non-parametric",
                                  trim_quantiles = c(0.01,0.99),
-                                 optimized_compile = TRUE,
                                  sl_lib = c("m_xgboost"),
                                  covar_bl_method = "absolute",
                                  covar_bl_trs = 0.1,
@@ -35,7 +34,7 @@ test_that("generate_pseudo_pop works as expected.", {
   expect_false(ps_pop1$passed_covar_test)
   expect_equal(nrow(ps_pop1$pseudo_pop), 490)
   expect_equal(ps_pop1$adjusted_corr_results$mean_absolute_corr,
-               0.2580037,
+               0.2580481,
                tolerance = 0.000001)
 
   # Test if all required attributes are included in the final object.
@@ -47,7 +46,6 @@ test_that("generate_pseudo_pop works as expected.", {
   expect_true(("passed_covar_test" %in% names(ps_pop1)))
   expect_true(("counter" %in% names(ps_pop1)))
   expect_true(("ci_appr" %in% names(ps_pop1)))
-  expect_true(("optimized_compile" %in% names(ps_pop1)))
   expect_true(("best_gps_used_params" %in% names(ps_pop1)))
   expect_true(("covariate_cols_name" %in% names(ps_pop1)))
 
@@ -58,7 +56,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                  ci_appr = "matching",
                                  gps_model = "parametric",
                                  trim_quantiles = c(0.04,0.96),
-                                 optimized_compile = TRUE,
                                  sl_lib = c("m_xgboost"),
                                  covar_bl_method = "absolute",
                                  covar_bl_trs = 0.1,
@@ -73,7 +70,7 @@ test_that("generate_pseudo_pop works as expected.", {
   expect_false(ps_pop2$passed_covar_test)
   expect_equal(nrow(ps_pop2$pseudo_pop), 460)
   expect_equal(ps_pop2$adjusted_corr_results$mean_absolute_corr,
-               0.2243034,
+               0.2241794,
                tolerance = 0.000001)
 
   # expect error with wrong ci_appr
@@ -84,7 +81,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    ci_appr = "grounding",
                                    gps_model = "parametric",
                                    trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = TRUE,
                                    sl_lib = c("m_xgboost"),
                                    covar_bl_method = "absolute",
                                    covar_bl_trs = 0.1,
@@ -103,7 +99,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    ci_appr = "matching",
                                    gps_model = "half-parametric",
                                    trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = TRUE,
                                    sl_lib = c("m_xgboost"),
                                    covar_bl_method = "absolute",
                                    covar_bl_trs = 0.1,
@@ -122,7 +117,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    ci_appr = "matching",
                                    gps_model = "parametric",
                                    trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = TRUE,
                                    sl_lib = c("m_xgboost"),
                                    covar_bl_method = "absolute",
                                    covar_bl_trs = 0.1,
@@ -133,25 +127,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    scale = 0.5,
                                    nthread = 1))
 
-  # expect error with wrong optimized compile answer
-  expect_error(generate_pseudo_pop(mydata$Y,
-                                   mydata$treat,
-                                   mydata[c("cf1","cf2","cf3","cf4","cf5",
-                                            "cf6","year","region")],
-                                   ci_appr = "matching",
-                                   gps_model = "parametric",
-                                   trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = "YES",
-                                   sl_lib = c("m_xgboost"),
-                                   covar_bl_method = "absolute",
-                                   covar_bl_trs = 0.1,
-                                   covar_bl_trs_type = "mean",
-                                   max_attempt = 1,
-                                   matching_fun = "matching_l1",
-                                   delta_n = 1,
-                                   scale = 0.5,
-                                   nthread = 1))
-
   # expect error with wrong covar_bl_method
   expect_error(generate_pseudo_pop(mydata$Y,
                                    mydata$treat,
@@ -160,7 +135,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    ci_appr = "matching",
                                    gps_model = "parametric",
                                    trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = TRUE,
                                    sl_lib = c("m_xgboost"),
                                    covar_bl_method = "nonabsolute",
                                    covar_bl_trs = 0.1,
@@ -180,7 +154,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    ci_appr = "matching",
                                    gps_model = "parametric",
                                    trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = TRUE,
                                    sl_lib = c("m_xgboost"),
                                    covar_bl_method = "absolute",
                                    covar_bl_trs = 0.1,
@@ -199,7 +172,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    ci_appr = "matching",
                                    gps_model = "parametric",
                                    trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = TRUE,
                                    use_cov_transform = "YES",
                                    transformers = list("pow2","pow3"),
                                    sl_lib = c("m_xgboost"),
@@ -221,7 +193,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    ci_appr = "matching",
                                    gps_model = "parametric",
                                    trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = TRUE,
                                    use_cov_transform = TRUE,
                                    transformers = numeric(),
                                    sl_lib = c("m_xgboost"),
@@ -243,7 +214,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                    ci_appr = "matching",
                                    gps_model = "parametric",
                                    trim_quantiles = c(0.04,0.96),
-                                   optimized_compile = TRUE,
                                    use_cov_transform = TRUE,
                                    sl_lib = c("m_xgboost"),
                                    covar_bl_method = "absolute",
@@ -262,7 +232,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                  ci_appr = "weighting",
                                  gps_model = "parametric",
                                  trim_quantiles = c(0.04,0.96),
-                                 optimized_compile = TRUE,
                                  sl_lib = c("m_xgboost"),
                                  covar_bl_method = "absolute",
                                  covar_bl_trs = 0.1,
@@ -277,7 +246,7 @@ test_that("generate_pseudo_pop works as expected.", {
   expect_false(ps_pop3$passed_covar_test)
   expect_equal(nrow(ps_pop3$pseudo_pop), 460)
   expect_equal(ps_pop3$adjusted_corr_results$mean_absolute_corr,
-               0.4481222,
+               0.3750209,
                tolerance = 0.000001)
 
   ps_pop4 <- generate_pseudo_pop(mydata$Y,
@@ -287,7 +256,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                  ci_appr = "matching",
                                  gps_model = "parametric",
                                  trim_quantiles = c(0.04,0.96),
-                                 optimized_compile = TRUE,
                                  use_cov_transform = TRUE,
                                  transformers = list("pow2","pow3"),
                                  sl_lib = c("m_xgboost"),
@@ -304,7 +272,7 @@ test_that("generate_pseudo_pop works as expected.", {
   expect_false(ps_pop4$passed_covar_test)
   expect_equal(nrow(ps_pop4$pseudo_pop), 460)
   expect_equal(ps_pop4$adjusted_corr_results$mean_absolute_corr,
-               0.2210705,
+               0.2209775,
                tolerance = 0.000001)
 
 
@@ -314,7 +282,6 @@ test_that("generate_pseudo_pop works as expected.", {
                                  ci_appr = "matching",
                                  gps_model = "parametric",
                                  trim_quantiles = c(0.04,0.96),
-                                 optimized_compile = TRUE,
                                  use_cov_transform = TRUE,
                                  transformers = list("pow2","pow3"),
                                  sl_lib = c("m_xgboost"),
@@ -331,8 +298,7 @@ test_that("generate_pseudo_pop works as expected.", {
   expect_false(ps_pop5$passed_covar_test)
   expect_equal(nrow(ps_pop4$pseudo_pop), 460)
   expect_equal(ps_pop5$adjusted_corr_results$mean_absolute_corr,
-               0.1078871,
+               0.1076907,
                tolerance = 0.000001)
 
-
 })
