@@ -1,9 +1,9 @@
 test_that("smooth_erf works as expected.", {
   val <- smooth_erf(matched_Y = pseudo_pop_covar_test$Y,
                     bw = 0.2,
-                    matched_w = pseudo_pop_covar_test$w)
+                    matched_w = pseudo_pop_covar_test$w,
+                    matched_cw = pseudo_pop_covar_test$w * 0)
 
   expect_equal(length(val), 2800)
-  expect_equal(val[150], -149.4658, tolerance=0.0001)
-
+  expect_equal(val[150], -149.4761, tolerance=0.0001)
 })
